@@ -1,5 +1,5 @@
 
-__version__ = '0.0.3'
+__version__ = '0.0.5'
 name = "pytorch-trainer"
 
 from pytorch_trainer.trainer import Trainer
@@ -8,5 +8,6 @@ from pytorch_trainer import hooks
 from pytorch_trainer import metrics
 from pytorch_trainer import utils
 from pytorch_trainer import visualizer
+from pytorch_trainer import datasets
 
-__all__ = [Trainer, configuration, hooks, metrics, utils, visualizer]
\ No newline at end of file
+__all__ = [Trainer, configuration, hooks, metrics, utils, visualizer, datasets]
\ No newline at end of file
